"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getReport = exports.exportStats = exports.addExtractionStats = exports.addBranchStats = void 0;
const tslib_1 = require("tslib");
const client_s3_1 = require("@aws-sdk/client-s3");
const is_1 = tslib_1.__importDefault(require("@sindresorhus/is"));
const logger_1 = require("../logger");
const fs_1 = require("../util/fs");
const s3_1 = require("../util/s3");
const report = {
    repositories: {},
};
function addBranchStats(config, branchesInformation) {
    if (is_1.default.nullOrUndefined(config.reportType)) {
        return;
    }
    coerceRepo(config.repository);
    report.repositories[config.repository].branches = branchesInformation;
}
exports.addBranchStats = addBranchStats;
function addExtractionStats(config, extractResult) {
    if (is_1.default.nullOrUndefined(config.reportType)) {
        return;
    }
    coerceRepo(config.repository);
    report.repositories[config.repository].packageFiles =
        extractResult.packageFiles;
}
exports.addExtractionStats = addExtractionStats;
async function exportStats(config) {
    try {
        if (is_1.default.nullOrUndefined(config.reportType)) {
            return;
        }
        if (config.reportType === 'logging') {
            logger_1.logger.info({ report }, 'Printing report');
            return;
        }
        if (config.reportType === 'file') {
            const path = config.reportPath;
            await (0, fs_1.writeSystemFile)(path, JSON.stringify(report));
            logger_1.logger.debug({ path }, 'Writing report');
            return;
        }
        if (config.reportType === 's3') {
            const s3Url = (0, s3_1.parseS3Url)(config.reportPath);
            if (is_1.default.nullOrUndefined(s3Url)) {
                logger_1.logger.warn({ reportPath: config.reportPath }, 'Failed to parse s3 URL');
                return;
            }
            const s3Params = {
                Bucket: s3Url.Bucket,
                Key: s3Url.Key,
                Body: JSON.stringify(report),
                ContentType: 'application/json',
            };
            const client = (0, s3_1.getS3Client)();
            const command = new client_s3_1.PutObjectCommand(s3Params);
            await client.send(command);
        }
    }
    catch (err) {
        logger_1.logger.warn({ err }, 'Reporting.exportStats() - failure');
    }
}
exports.exportStats = exportStats;
function getReport() {
    return structuredClone(report);
}
exports.getReport = getReport;
function coerceRepo(repository) {
    if (!is_1.default.undefined(report.repositories[repository])) {
        return;
    }
    report.repositories[repository] = {
        branches: [],
        packageFiles: {},
    };
}
//# sourceMappingURL=reporting.js.map